Authors / collaborators
=======================

``sig-networks`` is a library that applies models first developed in `Sequential Path Signature Networks for Personalised Longitudinal Language Modeling <https://aclanthology.org/2023.findings-acl.310/>`_ by Tseriotou et al. (2023) which presented a novel extension of neural sequential models using the notion of path signatures from rough path theory. The library is developed in collaboration with the `Research Engineering Team <https://www.turing.ac.uk/research-engineering>`_ at `The Alan Turing Institute <https://www.turing.ac.uk/>`_, and was originally written by `Talia Tseriotou <https://github.com/ttseriotou>`_ and `Ryan Chan <https://github.com/rchan26>`_.

We also thank `Kasra Hosseini <https://github.com/kasra-hosseini>`_ for his early contributions to the library, and to `Adam Tsakalidis <https://scholar.google.co.uk/citations?user=uZrHOAgAAAAJ&hl=en>`_, `Maria Likata <https://scholar.google.co.uk/citations?user=eys5GB4AAAAJ&hl=en>`_, and `Terry Lyons <https://www.maths.ox.ac.uk/people/terry.lyons>`_ for their valuable guidance and advice.

For an up-to-date list of collaborators to the library, please see the `GitHub repo <https://github.com/ttseriotou/sig-networks>`_ for this package.
